import { z } from 'zod';
export type ContractData = z.infer<typeof data>;
export type ContractTemplate = z.infer<typeof template>;
export type Endorsement = z.infer<typeof endorsement>;
export type Signature = z.infer<typeof signature>;
declare const endorsement: z.ZodObject<{
    hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
}, "strip", z.ZodTypeAny, {
    pubkey: string;
    hash: string;
    signature: string;
}, {
    pubkey: string;
    hash: string;
    signature: string;
}>, signature: z.ZodObject<{
    pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    partial_sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
}, "strip", z.ZodTypeAny, {
    pubkey: string;
    nonce: string;
    partial_sig: string;
}, {
    pubkey: string;
    nonce: string;
    partial_sig: string;
}>;
declare const template: z.ZodObject<{
    title: z.ZodString;
    description: z.ZodOptional<z.ZodString>;
    terms: z.ZodOptional<z.ZodString>;
    agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
    members: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
    records: z.ZodOptional<z.ZodArray<z.ZodObject<{
        type: z.ZodEnum<["data", "profile", "script", "term"]>;
        label: z.ZodString;
        content: z.ZodArray<z.ZodString, "many">;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }, {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }>, "many">>;
}, "strip", z.ZodTypeAny, {
    title: string;
    description?: string | undefined;
    terms?: string | undefined;
    agent?: string | undefined;
    members?: string[] | undefined;
    records?: {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }[] | undefined;
}, {
    title: string;
    description?: string | undefined;
    terms?: string | undefined;
    agent?: string | undefined;
    members?: string[] | undefined;
    records?: {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }[] | undefined;
}>;
declare const data: z.ZodObject<{
    info: z.ZodObject<{
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        terms: z.ZodOptional<z.ZodString>;
        admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        title: string;
        admin: string;
        agent: string;
        description?: string | undefined;
        terms?: string | undefined;
    }, {
        title: string;
        admin: string;
        agent: string;
        description?: string | undefined;
        terms?: string | undefined;
    }>;
    meta: z.ZodObject<{
        block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        open_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        close_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }, {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    }>;
    room: z.ZodObject<{
        secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        pubkey: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        hash: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string | null;
        nonce: string | null;
        hash: string | null;
        secret: string;
    }, {
        pubkey: string | null;
        nonce: string | null;
        hash: string | null;
        secret: string;
    }>;
    status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    revision: z.ZodNumber;
    created_at: z.ZodDate;
    updated_at: z.ZodDate;
    endorsements: z.ZodArray<z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        hash: string;
        signature: string;
    }, {
        pubkey: string;
        hash: string;
        signature: string;
    }>, "many">;
    profiles: z.ZodArray<z.ZodObject<{
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        alias: z.ZodString;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        updated_at: Date;
        nonce: string;
        alias: string;
    }, {
        pubkey: string;
        updated_at: Date;
        nonce: string;
        alias: string;
    }>, "many">;
    records: z.ZodArray<z.ZodObject<{
        type: z.ZodEnum<["data", "profile", "script", "term"]>;
        label: z.ZodString;
        content: z.ZodArray<z.ZodString, "many">;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        updated_at: z.ZodDate;
    }, "strip", z.ZodTypeAny, {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }, {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }>, "many">;
    signatures: z.ZodArray<z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        partial_sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }, {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }>, "many">;
    transactions: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
}, "strip", z.ZodTypeAny, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    info: {
        title: string;
        admin: string;
        agent: string;
        description?: string | undefined;
        terms?: string | undefined;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        nonce: string | null;
        hash: string | null;
        secret: string;
    };
    members: string[];
    contract_id: string;
    revision: number;
    created_at: Date;
    endorsements: {
        pubkey: string;
        hash: string;
        signature: string;
    }[];
    profiles: {
        pubkey: string;
        updated_at: Date;
        nonce: string;
        alias: string;
    }[];
    records: {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }[];
    signatures: {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }[];
    transactions: string[];
}, {
    status: "draft" | "published" | "active" | "disputed" | "closed";
    updated_at: Date;
    info: {
        title: string;
        admin: string;
        agent: string;
        description?: string | undefined;
        terms?: string | undefined;
    };
    meta: {
        block_id: string;
        open_txid: string | null;
        close_txid: string | null;
    };
    room: {
        pubkey: string | null;
        nonce: string | null;
        hash: string | null;
        secret: string;
    };
    members: string[];
    contract_id: string;
    revision: number;
    created_at: Date;
    endorsements: {
        pubkey: string;
        hash: string;
        signature: string;
    }[];
    profiles: {
        pubkey: string;
        updated_at: Date;
        nonce: string;
        alias: string;
    }[];
    records: {
        type: "data" | "profile" | "script" | "term";
        pubkey: string;
        label: string;
        content: string[];
        updated_at: Date;
    }[];
    signatures: {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }[];
    transactions: string[];
}>;
export declare const ContractSchema: {
    data: z.ZodObject<{
        info: z.ZodObject<{
            title: z.ZodString;
            description: z.ZodOptional<z.ZodString>;
            terms: z.ZodOptional<z.ZodString>;
            admin: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            agent: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        }, {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        }>;
        meta: z.ZodObject<{
            block_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            open_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            close_txid: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }, {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        }>;
        room: z.ZodObject<{
            secret: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            nonce: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            pubkey: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
            hash: z.ZodUnion<[z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, z.ZodNull]>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string | null;
            nonce: string | null;
            hash: string | null;
            secret: string;
        }, {
            pubkey: string | null;
            nonce: string | null;
            hash: string | null;
            secret: string;
        }>;
        status: z.ZodEnum<["draft", "published", "active", "disputed", "closed"]>;
        members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
        contract_id: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        revision: z.ZodNumber;
        created_at: z.ZodDate;
        updated_at: z.ZodDate;
        endorsements: z.ZodArray<z.ZodObject<{
            hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            hash: string;
            signature: string;
        }, {
            pubkey: string;
            hash: string;
            signature: string;
        }>, "many">;
        profiles: z.ZodArray<z.ZodObject<{
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            alias: z.ZodString;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }, {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }>, "many">;
        records: z.ZodArray<z.ZodObject<{
            type: z.ZodEnum<["data", "profile", "script", "term"]>;
            label: z.ZodString;
            content: z.ZodArray<z.ZodString, "many">;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }, {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }>, "many">;
        signatures: z.ZodArray<z.ZodObject<{
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            partial_sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        }, "strip", z.ZodTypeAny, {
            pubkey: string;
            nonce: string;
            partial_sig: string;
        }, {
            pubkey: string;
            nonce: string;
            partial_sig: string;
        }>, "many">;
        transactions: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    }, "strip", z.ZodTypeAny, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        info: {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            nonce: string | null;
            hash: string | null;
            secret: string;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        endorsements: {
            pubkey: string;
            hash: string;
            signature: string;
        }[];
        profiles: {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }[];
        records: {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }[];
        signatures: {
            pubkey: string;
            nonce: string;
            partial_sig: string;
        }[];
        transactions: string[];
    }, {
        status: "draft" | "published" | "active" | "disputed" | "closed";
        updated_at: Date;
        info: {
            title: string;
            admin: string;
            agent: string;
            description?: string | undefined;
            terms?: string | undefined;
        };
        meta: {
            block_id: string;
            open_txid: string | null;
            close_txid: string | null;
        };
        room: {
            pubkey: string | null;
            nonce: string | null;
            hash: string | null;
            secret: string;
        };
        members: string[];
        contract_id: string;
        revision: number;
        created_at: Date;
        endorsements: {
            pubkey: string;
            hash: string;
            signature: string;
        }[];
        profiles: {
            pubkey: string;
            updated_at: Date;
            nonce: string;
            alias: string;
        }[];
        records: {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }[];
        signatures: {
            pubkey: string;
            nonce: string;
            partial_sig: string;
        }[];
        transactions: string[];
    }>;
    members: z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">;
    endorsement: z.ZodObject<{
        hash: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        signature: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        hash: string;
        signature: string;
    }, {
        pubkey: string;
        hash: string;
        signature: string;
    }>;
    signature: z.ZodObject<{
        pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        nonce: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
        partial_sig: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
    }, "strip", z.ZodTypeAny, {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }, {
        pubkey: string;
        nonce: string;
        partial_sig: string;
    }>;
    template: z.ZodObject<{
        title: z.ZodString;
        description: z.ZodOptional<z.ZodString>;
        terms: z.ZodOptional<z.ZodString>;
        agent: z.ZodOptional<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>>;
        members: z.ZodOptional<z.ZodArray<z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>, "many">>;
        records: z.ZodOptional<z.ZodArray<z.ZodObject<{
            type: z.ZodEnum<["data", "profile", "script", "term"]>;
            label: z.ZodString;
            content: z.ZodArray<z.ZodString, "many">;
            pubkey: z.ZodEffects<z.ZodEffects<z.ZodString, string, string>, string, string>;
            updated_at: z.ZodDate;
        }, "strip", z.ZodTypeAny, {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }, {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
        agent?: string | undefined;
        members?: string[] | undefined;
        records?: {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }[] | undefined;
    }, {
        title: string;
        description?: string | undefined;
        terms?: string | undefined;
        agent?: string | undefined;
        members?: string[] | undefined;
        records?: {
            type: "data" | "profile" | "script" | "term";
            pubkey: string;
            label: string;
            content: string[];
            updated_at: Date;
        }[] | undefined;
    }>;
};
export {};
//# sourceMappingURL=contract.d.ts.map